<?php

namespace Drupal\inxmail_xml\Form;

use Drupal\Core\Form\ConfigFormBase;
use Drupal\Core\Form\FormStateInterface;

/**
 * Class InxmailXmlSettingsForm.
 */
class InxmailXmlSettingsForm extends ConfigFormBase {

  /**
   * {@inheritdoc}
   */
  protected function getEditableConfigNames() {
    return [
      'inxmail_xml.settings',
    ];
  }

  /**
   * {@inheritdoc}
   */
  public function getFormId() {
    return 'inxmail_xml_admin_settings';
  }

  /**
   * {@inheritdoc}
   */
  public function buildForm(array $form, FormStateInterface $form_state) {
    $this->setDefaultConfigValues();

    $config = $this->config('inxmail_xml.settings');

    $form['configuration'] = [
      '#type' => 'details',
      '#title' => $this->t('Configuration'),
      '#open' => TRUE,
    ];
//    $form['configuration']['content_type'] = [
//      '#type' => 'textfield',
//      '#title' => $this->t('Content type'),
//      '#maxlength' => 255,
//      '#default_value' => $config->get('content_type'),
//      '#description' => $this->t('Machine name of the content type, e.g.: article'),
//    ];
//    $form['configuration']['xml_header'] = [
//      '#type' => 'textarea',
//      '#title' => $this->t('XML Header'),
//      '#default_value' => $config->get('xml_header'),
//    ];
//    $form['configuration']['xml_footer'] = [
//      '#type' => 'textarea',
//      '#title' => $this->t('XML Footer'),
//      '#default_value' => $config->get('xml_footer'),
//    ];
    return parent::buildForm($form, $form_state);
  }

  /**
   * {@inheritdoc}
   */
  public function validateForm(array &$form, FormStateInterface $form_state) {
    parent::validateForm($form, $form_state);
  }

  /**
   * {@inheritdoc}
   */
  public function submitForm(array &$form, FormStateInterface $form_state) {
    parent::submitForm($form, $form_state);

    $this->config('inxmail_xml.settings')
      ->set('content_type', $form_state->getValue('content_type'))
      ->set('xml_header', $form_state->getValue('xml_header'))
      ->set('xml_footer', $form_state->getValue('xml_footer'))
      ->save();
  }

  /**
   * Set default config values.
   */
  private function setDefaultConfigValues() {
    $defaultConfigValues = [
      'content_type' => 'articles',
      'xml_header' => '<sidebar_article News="News" _inx_tds_config="tdsId;419" auto-generate="true" lang="Sidebar-Artikel">
      <Paragraph_ad_category _inx_tds_config="" auto-generate="true" lang="Kategorie" lines="1">Category title</Paragraph_ad_category>
      <Title_ad _inx_tds_config="" auto-generate="true" lang="Title" lines="1"/>
      <GroupImageLink_ad _inx_tds_config="" auto-generate="true" lang="Image" orientation="horizontal">
      <Image_GroupImageLink_ad _inx_tds_config="" auto-generate="true" component="image" grow="false" help="Fix&amp;amp;nbsp;width: 216px." lang="Image" maxfilesize="30" rendering="empty" size="216x*">&lt;img src="[%url:unique-count; "https://www.site.org/themes/contrib/my_theme/images/logo_.gif"]" alt="" width="150" height="36" border="0" /&gt;</Image_GroupImageLink_ad>
      <Link_GroupImageLink_ad NoContent="NoContent" _inx_tds_config="" auto-generate="true" autotest="true" component="url" grow="true" lang="Image" tracking-type="normal-tracking">[%url:unique-count; "https://www.site.org"]</Link_GroupImageLink_ad>
      <Thumbnail_GroupImageLink_ad _inx_tds_config="" auto-generate="true" component="thumbnail" grow="false" infoalignment="bottom" lang="Vorschau" maxfilesize="30" showinfo="true" size="216x*" thumbnailsize="150x120" xpath="../Image_GroupImageLink_ad"> </Thumbnail_GroupImageLink_ad>
      </GroupImageLink_ad>
      <Paragraph_img_text _inx_tds_config="" auto-generate="true" lang="Image" lines="2"/>
      <Paragraph_ad _inx_tds_config="" auto-generate="true" lang="Text" lines="4">',
      'xml_footer' => '</Paragraph_ad>
      <Link_ad _inx_tds_config="" auto-generate="true" autotest="true" component="url" lang="Link" tracking-type="tracking-only"/>
      <ad_company _inx_tds_config="" auto-generate="true" lang="Information">
      <Paragraph_ad_company _inx_tds_config="" auto-generate="true" lang="Text" lines="1"> </Paragraph_ad_company>
      <Checkbox_break _inx_tds_config="" auto-generate="true" component="checkbox" default="true" labelalignment="left" lang="New line">true</Checkbox_break>
      <Link_ad_company _inx_tds_config="" auto-generate="true" autotest="true" component="url" lang="Link" tracking-type="normal-tracking"> </Link_ad_company>
      </ad_company>
      <Checkbox_sharing_links _inx_tds_config="" auto-generate="true" component="checkbox" default="true" labelalignment="left" lang="Sharing-Links">true</Checkbox_sharing_links>
      </sidebar_article>',
    ];

    foreach ($defaultConfigValues as $config => $value) {
      $this->setConfigValue($config, $value);
    }
  }

  /**
   * Set config value.
   */
  private function setConfigValue($config, $value) {
    if (empty($this->config('inxmail_xml.settings')->get($config))) {
      $this->config('inxmail_xml.settings')
        ->set($config, $value)
        ->save();
    }
  }
}
